==> nextcloud-31.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Information CPU non disponible",
    "CPU Usage:" : "Usage CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Moyenne de la charge : {percentage}% ( {load}) dernière minute",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) dernière Minute\n{last5MinutesPercentage} % ({last5Minutes}) 5 dernières Minutes\n{last15MinutesPercentage} % ({last15Minutes}) 15 dernières Minutes",
    "RAM Usage:" : "Usage RAM:",
    "SWAP Usage:" : "Usage SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM : Total : {memTotalBytes}/Utilisation actuelle : {memUsageBytes}",
    "RAM info not available" : "Informations sur la RAM non disponibles",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP : Total : {swapTotalBytes}/Utilisation actuelle : {swapUsageBytes}",
    "SWAP info not available" : "L'information SWAP n'est pas disponible",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté !",
    "Press ⌘-C to copy." : "Pressez ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "System" : "Système",
    "Monitoring" : "Surveillance",
    "Monitoring app with useful server information" : "Application de surveillance avec les informations utiles du serveur",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fournit des informations utiles sur le serveur, telles que la charge du processeur, l'utilisation de la RAM, l'utilisation du disque, le nombre d'utilisateurs, etc.",
    "Operating System:" : "Système d’exploitation :",
    "CPU:" : "CPU :",
    "Unknown Processor" : "Processeur inconnu",
    "Memory:" : "Mémoire :",
    "Server time:" : "Heure du serveur :",
    "Uptime:" : "Durée de fonctionnement :",
    "Temperature" : "Température",
    "Load" : "Charge",
    "Memory" : "Mémoire",
    "Disk" : "Disque",
    "Mount:" : "Montage :",
    "Filesystem:" : "Système de fichiers :",
    "Size:" : "Taille :",
    "Available:" : "Disponible :",
    "Used:" : "Utilisé :",
    "Files:" : "Fichiers :",
    "Storages:" : "Stockages :",
    "Free Space:" : "Espace libre :",
    "Network" : "Réseau",
    "Hostname:" : "Nom d'hôte :",
    "Gateway:" : "Passerelle :",
    "Status:" : "État :",
    "Speed:" : "Vitesse :",
    "Duplex:" : "Duplex :",
    "MAC:" : "MAC :",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Utilisateurs actifs",
    "Last hour" : "Dernière heure",
    "%s%% of all users" : "%s%% pour tous les utilisateurs",
    "Last 24 Hours" : "Dernières 24 heures",
    "Last 7 Days" : "7 derniers jours",
    "Last 30 Days" : "30 derniers jours",
    "Shares" : "Partages",
    "Users:" : "Utilisateurs :",
    "Groups:" : "Groupes :",
    "Links:" : "Liens :",
    "Emails:" : "E-mails :",
    "Federated sent:" : "Offre de fédération envoyée :",
    "Federated received:" : "Offre de fédération reçue :",
    "Talk conversations:" : "Conversations Talk :",
    "PHP" : "PHP",
    "Version:" : "Version :",
    "Memory limit:" : "Limite de mémoire :",
    "Max execution time:" : "Temps d’exécution maximal :",
    "Upload max size:" : "Taille de téléversement maximale :",
    "OPcache Revalidate Frequency:" : "Fréquence de revalidation de l'OPcache :",
    "Extensions:" : "Extensions :",
    "Unable to list extensions" : "Impossible de lister les extensions",
    "Show phpinfo" : "Afficher phpinfo",
    "Database" : "Base de données",
    "Type:" : "Type :",
    "External monitoring tool" : "Outil de surveillance externe",
    "Use this end point to connect an external monitoring tool:" : "Utiliser ce point de terminaison pour connecter un outil de surveillance externe :",
    "Copy" : "Copier",
    "Output in JSON" : "Sortie en JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Ignorer la section des applications (y compris la section des applications enverra une demande externe à l'App Store)",
    "Skip server update" : "Ignorer la mise à jour du serveur",
    "To use an access token, please generate one then set it using the following command:" : "Pour utiliser un jeton d'accès, veuillez en générer un puis le définir à l'aide de la commande suivante :",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Puis transmettez le jeton avec l’entête « NC-Token » lorsque vous appelez l’URL."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informations CPU non disponibles",
    "CPU Usage:" : "Utilisation CPU :",
    "Load average: {percentage} % ({load}) last minute" : "Charge moyenne : {percentage}% ( {load}) dernière minute",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) la dernière minute\n{last5MinutesPercentage} % ({last5Minutes}) les 5 dernières minutes\n{last15MinutesPercentage} % ({last15Minutes}) les 15 dernières minutes",
    "RAM Usage:" : "Utilisation RAM :",
    "SWAP Usage:" : "Utilisation SWAP :",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM : Total : {memTotalBytes} / Utilisation actuelle : {memUsageBytes}",
    "RAM info not available" : "Informations RAM non disponibles",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP : Total : {swapTotalBytes} / Utilisation actuelle : {swapUsageBytes}",
    "SWAP info not available" : "Informations SWAP non disponibles",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté !",
    "Press ⌘-C to copy." : "Appuyer sur ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "Unknown" : "Inconnu",
    "System" : "Système",
    "Monitoring" : "Surveillance",
    "Monitoring app with useful server information" : "Application de surveillance avec les informations utiles du serveur",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fournit des informations utiles sur le serveur, telles que la charge du processeur, l'utilisation de la RAM, l'utilisation du disque, le nombre d'utilisateurs, etc.",
    "Operating System:" : "Système d’exploitation :",
    "CPU:" : "CPU :",
    "threads" : "fil de discussion",
    "Memory:" : "Mémoire :",
    "Server time:" : "Heure du serveur :",
    "Uptime:" : "Durée de fonctionnement :",
    "Temperature" : "Température",
    "Load" : "Charge",
    "Memory" : "Mémoire",
    "Disk" : "Disque",
    "Mount:" : "Montage :",
    "Filesystem:" : "Système de fichiers :",
    "Size:" : "Taille :",
    "Available:" : "Disponible :",
    "Used:" : "Utilisé :",
    "Files:" : "Fichiers :",
    "Storages:" : "Stockages :",
    "Free Space:" : "Espace libre :",
    "Network" : "Réseau",
    "Hostname:" : "Nom d'hôte :",
    "Gateway:" : "Passerelle :",
    "Status:" : "État :",
    "Speed:" : "Vitesse :",
    "Duplex:" : "Duplex :",
    "MAC:" : "MAC :",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Utilisateurs actifs",
    "Last hour" : "Dernière heure",
    "%s%% of all users" : "%s%% pour tous les utilisateurs",
    "Last 24 Hours" : "Dernières 24 heures",
    "Last 7 Days" : "7 derniers jours",
    "Last 30 Days" : "30 derniers jours",
    "Shares" : "Partages",
    "Users:" : "Utilisateurs :",
    "Groups:" : "Groupes :",
    "Links:" : "Liens :",
    "Emails:" : "E-mails :",
    "Federated sent:" : "Offre de fédération envoyée :",
    "Federated received:" : "Offre de fédération reçue :",
    "Talk conversations:" : "Conversations Talk :",
    "PHP" : "PHP",
    "Version:" : "Version :",
    "Memory limit:" : "Limite de mémoire :",
    "Max execution time:" : "Temps d’exécution maximal :",
    "seconds" : "secondes",
    "Upload max size:" : "Taille de téléversement maximale :",
    "OPcache Revalidate Frequency:" : "Fréquence de revalidation de l'OPcache :",
    "Extensions:" : "Extensions :",
    "Unable to list extensions" : "Impossible de lister les extensions",
    "Show phpinfo" : "Afficher phpinfo",
    "FPM worker pool" : "pool du worker FPM",
    "Pool name:" : "Nom du pool :",
    "Pool type:" : "Type de pool :",
    "Start time:" : "Heure de début :",
    "Accepted connections:" : "Connexions acceptées :",
    "Total processes:" : "Nombre total de processus :",
    "Active processes:" : "Processus actifs :",
    "Idle processes:" : "Processus inactifs :",
    "Listen queue:" : "File d'attente d'écoute :",
    "Slow requests:" : "Requêtes lentes :",
    "Max listen queue:" : "File d'attente d'écoute maximale :",
    "Max active processes:" : "Nombre maximal de processus actifs :",
    "Max children reached:" : "Nombre maximal d'enfants atteint :",
    "Database" : "Base de données",
    "Type:" : "Type :",
    "External monitoring tool" : "Outil de surveillance externe",
    "Use this end point to connect an external monitoring tool:" : "Utiliser ce point de terminaison pour connecter un outil de surveillance externe :",
    "Copy" : "Copier",
    "Output in JSON" : "Sortie en JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Ignorer la section des applications (y compris la section des applications enverra une demande externe à l'App Store)",
    "Skip server update" : "Ignorer la mise à jour du serveur",
    "To use an access token, please generate one then set it using the following command:" : "Pour utiliser un jeton d'accès, veuillez en générer un puis le définir à l'aide de la commande suivante :",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Puis transmettez le jeton avec l’entête « NC-Token » lorsque vous appelez l’URL.",
    "Unknown Processor" : "Processeur inconnu"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
